@@ -12,13 +12,13 @@ import (
 	"github.com/jandedobbeleer/oh-my-posh/src/log"
 	"github.com/jandedobbeleer/oh-my-posh/src/regex"
 	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
+	runjobs "github.com/jandedobbeleer/oh-my-posh/src/runtime/jobs"
 	"github.com/jandedobbeleer/oh-my-posh/src/segments/options"
 	"github.com/jandedobbeleer/oh-my-posh/src/template"
 
-	toml "github.com/pelletier/go-toml/v2"
+	"go.yaml.in/yaml/v3"
 	c "golang.org/x/text/cases"
 	"golang.org/x/text/language"
-	"gopkg.in/yaml.v3"
 )
 
 // SegmentStyle the style of segment, for more information, see the constants
@@ -36,9 +36,12 @@ func (s *SegmentStyle) resolve(context any) SegmentStyle {
 }
 
 type Segment struct {
-	writer                 SegmentWriter
-	env                    runtime.Environment
-	Options                options.Map `json:"options,omitempty" toml:"options,omitempty" yaml:"options,omitempty"`
+	writer  SegmentWriter
+	env     runtime.Environment
+	Options options.Map `json:"options,omitempty" toml:"options,omitempty" yaml:"options,omitempty"`
+	// Properties is deprecated, use Options instead. This field exists for TOML backward compatibility
+	// since go-toml/v2 doesn't support custom unmarshalers. It will be migrated to Options after loading.
+	Properties             options.Map `json:"-" toml:"properties,omitempty" yaml:"-"`
 	Cache                  *Cache      `json:"cache,omitempty" toml:"cache,omitempty" yaml:"cache,omitempty"`
 	Alias                  string      `json:"alias,omitempty" toml:"alias,omitempty" yaml:"alias,omitempty"`
 	styleCache             SegmentStyle
@@ -61,7 +64,7 @@ type Segment struct {
 	ExcludeFolders         []string       `json:"exclude_folders,omitempty" toml:"exclude_folders,omitempty" yaml:"exclude_folders,omitempty"`
 	IncludeFolders         []string       `json:"include_folders,omitempty" toml:"include_folders,omitempty" yaml:"include_folders,omitempty"`
 	Needs                  []string       `json:"-" toml:"-" yaml:"-"`
-	Timeout                time.Duration  `json:"timeout,omitempty" toml:"timeout,omitempty" yaml:"timeout,omitempty"`
+	Timeout                int            `json:"timeout,omitempty" toml:"timeout,omitempty" yaml:"timeout,omitempty"`
 	MaxWidth               int            `json:"max_width,omitempty" toml:"max_width,omitempty" yaml:"max_width,omitempty"`
 	MinWidth               int            `json:"min_width,omitempty" toml:"min_width,omitempty" yaml:"min_width,omitempty"`
 	Duration               time.Duration  `json:"-" toml:"-" yaml:"-"`
@@ -126,21 +129,13 @@ func (segment *Segment) UnmarshalYAML(node *yaml.Node) error {
 	return modifiedNode.Decode((*segmentAlias)(segment))
 }
 
-func (segment *Segment) UnmarshalTOML(data []byte) error {
-	aux := &segmentAux{
-		segmentAlias: (*segmentAlias)(segment),
+// MigratePropertiesToOptions migrates the deprecated Properties field to Options.
+// This is needed for TOML configs since go-toml/v2 doesn't support custom unmarshalers.
+func (segment *Segment) MigratePropertiesToOptions() {
+	if len(segment.Properties) > 0 && len(segment.Options) == 0 {
+		segment.Options = segment.Properties
+		segment.Properties = nil
 	}
-
-	if err := toml.Unmarshal(data, aux); err != nil {
-		return err
-	}
-
-	// Migrate 'properties' to 'options' if present
-	if len(aux.Properties) > 0 && len(segment.Options) == 0 {
-		segment.Options = aux.Properties
-	}
-
-	return nil
 }
 
 func (segment *Segment) Name() string {
@@ -189,27 +184,18 @@ func (segment *Segment) Execute(env runtime.Environment) {
 		return
 	}
 
-	if segment.Timeout == 0 {
-		segment.Enabled = segment.writer.Enabled()
-	} else {
-		done := make(chan bool)
-		go func() {
-			segment.Enabled = segment.writer.Enabled()
-			done <- true
-		}()
-
-		select {
-		case <-done:
-			// Completed before timeout
-		case <-time.After(segment.Timeout * time.Millisecond):
-			log.Debugf("timeout after %dms for segment: %s", segment.Timeout, segment.Name())
-			return
+	defer func() {
+		if segment.Enabled {
+			template.Cache.AddSegmentData(segment.Name(), segment.writer)
 		}
+	}()
+
+	// Create Job for this goroutine so child processes can be tracked and killed on timeout
+	if err := runjobs.CreateJobForGoroutine(segment.Name()); err != nil {
+		log.Errorf("failed to create job for goroutine (segment: %s): %v", segment.Name(), err)
 	}
 
-	if segment.Enabled {
-		template.Cache.AddSegmentData(segment.Name(), segment.writer)
-	}
+	segment.Enabled = segment.writer.Enabled()
 }
 
 func (segment *Segment) Render(index int, force bool) bool {
@@ -318,10 +304,10 @@ func (segment *Segment) restoreCache() bool {
 		return false
 	}
 
-	cacheKey := segment.cacheKey()
-	data, OK := cache.Get[string](cache.Session, cacheKey)
+	key, store := segment.cacheKeyAndStore()
+	data, OK := cache.Get[string](store, key)
 	if !OK {
-		log.Debugf("no cache found for segment: %s, key: %s", segment.Name(), cacheKey)
+		log.Debugf("no cache found for segment: %s, key: %s", segment.Name(), key)
 		return false
 	}
 
@@ -354,18 +340,21 @@ func (segment *Segment) setCache() {
 	// TODO: check if we can make segmentwriter a generic Type indicator
 	// that way we can actually get the value straight from cache.Get
 	// and marchalling is obsolete
-	cache.Set(cache.Session, segment.cacheKey(), string(data), segment.Cache.Duration)
+	key, store := segment.cacheKeyAndStore()
+	cache.Set(store, key, string(data), segment.Cache.Duration)
 }
 
-func (segment *Segment) cacheKey() string {
+func (segment *Segment) cacheKeyAndStore() (string, cache.Store) {
 	format := "segment_cache_%s"
 	switch segment.Cache.Strategy {
 	case Session:
-		return fmt.Sprintf(format, segment.Name())
+		return fmt.Sprintf(format, segment.Name()), cache.Session
+	case Device:
+		return fmt.Sprintf(format, segment.Name()), cache.Device
 	case Folder:
 		fallthrough
 	default:
-		return fmt.Sprintf(format, strings.Join([]string{segment.Name(), segment.folderKey()}, "_"))
+		return fmt.Sprintf(format, strings.Join([]string{segment.Name(), segment.folderKey()}, "_")), cache.Device
 	}
 }
 
