@@ -1,6 +1,4 @@
-const path = require('path');
-
-module.exports = {
+export default {
   title: 'Oh My Posh',
   tagline: 'The most customizable and fastest prompt engine for any shell.',
   url: 'https://ohmyposh.dev',
@@ -10,7 +8,7 @@ module.exports = {
   projectName: 'oh-my-posh',
   onBrokenLinks: 'ignore',
   plugins: [
-    path.resolve(__dirname, 'plugins', 'appinsights')
+    './plugins/appinsights'
   ],
   stylesheets: [
     "https://rsms.me/inter/inter.css",
@@ -23,7 +21,7 @@ module.exports = {
       respectPrefersColorScheme: true,
     },
     prism: {
-      additionalLanguages: ['powershell', 'lua', 'jsstacktrace', 'toml', 'json', 'yaml'],
+      additionalLanguages: ['powershell', 'lua', 'jsstacktrace', 'toml'],
     },
     docs: {
         sidebar: {
@@ -54,11 +52,6 @@ module.exports = {
           label: 'Sponsor',
           position: 'left',
         },
-        {
-          href: 'https://polar.sh/oh-my-posh',
-          label: 'Buy',
-          position: 'left',
-        },
         {
           href: 'https://swag.ohmyposh.dev',
           label: 'Swag',
@@ -70,12 +63,6 @@ module.exports = {
           'aria-label': 'GitHub repository',
           position: 'right',
         },
-        {
-          href: 'https://www.warp.dev/oh-my-posh',
-          className: 'header-affiliate-link',
-          'aria-label': 'Warp',
-          position: 'right',
-        },
         {
           href: 'https://discord.gg/n7E3DkXssv',
           className: 'header-discord-link',
@@ -131,12 +118,8 @@ module.exports = {
               href: 'https://github.com/sponsors/JanDeDobbeleer',
             },
             {
-              label: 'Buy',
-              href: 'https://polar.sh/oh-my-posh',
-            },
-            {
-              label: 'Warp',
-              href: 'https://www.warp.dev/oh-my-posh',
+              label: 'Product spotlight',
+              href: 'https://buy.polar.sh/polar_cl_qnmZxboq1IDUJo03mk2Jue6ktqZrCXElnzH2s2xbV2R',
             },
             {
               label: 'Docusaurus',
@@ -147,6 +130,15 @@ module.exports = {
               href: '/privacy',
             },
           ],
+        },
+                {
+          title: 'Sponsors',
+          items: [
+            {
+              label: 'Merge Conflict',
+              href: 'https://www.mergeconflict.fm/',
+            },
+          ],
         },
       ],
       copyright: `Copyright © ${new Date().getFullYear()} <a href='https://github.com/sponsors/JanDeDobbeleer' target='_blank'>Jan De Dobbeleer</a> and <a href='/docs/contributors'>contributors</a>.`,
@@ -173,13 +165,13 @@ module.exports = {
       '@docusaurus/preset-classic',
       {
         docs: {
-          sidebarPath: require.resolve('./sidebars.js'),
+          sidebarPath: './sidebars.js',
           editUrl: 'https://github.com/jandedobbeleer/oh-my-posh/edit/main/website/',
         },
         theme: {
           customCss: [
-            require.resolve('./src/css/prism-rose-pine-moon.css'),
-            require.resolve('./src/css/custom.css')
+            './src/css/prism-rose-pine-moon.css',
+            './src/css/custom.css'
           ],
         },
         blog: {
